/* step3 　2013-07-03 　*/
#include "dm3.h"
#include <time.h>
#include <stdlib.h>

#define ROW       22  // フィールドの行数
#define COLUMN 11  // フィールドの列数

double R[12] = {1,0,0,0, 0,1,0,0, 0,0,1,0}; // 回転行列が格納される配列, 位置(x,y,z)[m]
double start_x =  5.5, start_y = 0.5, start_z = 0.0; // 壁の初期位置
double start_bx = 10.5, start_by = 20.5, start_bz = 0.5; // ブロックの初期位置

double wall_p[3] = {0.0, 0.0, 0.5};   // 壁の位置(x,y,z)[m]
double block_p[100][3]; // ロボットの位置
double sides[3] = {1.0, 1.0, 1.0}; // 直方体のサイズ(x, y, z)[m]
float black[3] = {0, 0, 0}, green[3] = {0,1,0},red[3] = {1,0,0}; // 黒色，緑色，赤色
int       now = 0; // 現在、操作可能なブロック番号

int field[ROW][COLUMN] =  // フィールド
{
    {1,1,1,1,1,1,1,1,1,1,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,0,0,0,0,0,0,0,0,0,1},
    {1,1,1,1,1,1,1,1,1,1,1}
};

void command(int cmd)
{
    switch (cmd)
    {
    case 'a':
        if (block_p[now][0] > 1.5)  block_p[now][0] -= 1.0;
        break;
    case 'd':
        if (block_p[now][0] < 18.5) block_p[now][0] += 1.0;
        break;
    default:
        printf("Key is %c: Input a,d,w,x,r\n",(char)cmd);
    }
}

// フィールドの描画
void drawField()
{
    int i, j;
    for (i = 0; i < ROW; i++)
    {
        for (j = 0; j < COLUMN; j++)
        {
            if (field[i][j] == 1)
            {
                dsSetColor(1.0, 0.0, 0.0); // 色の設定
                wall_p[0] = j  + start_x;       // 位置のx成分
                wall_p[1] = i  + start_y;       // 位置のx成分
                wall_p[2] = 0.5;                 // 位置のz成分
                dsDrawBox(wall_p,R,sides); // 直方体の表示
            }
        }
    }
}

// ブロックの初期化
void initBlock()
{
    block_p[now][0] = start_bx;
    block_p[now][1] = start_by;
    block_p[now][2] = start_bz;
}

// ブロックの描画
void drawBlock()
{
    int i;

    if (block_p[now][1] >1.5)   // 下の壁を突き抜けない
    {
        block_p[now][1] -= 0.1; // ブロックの落下
    }
    else
    {
        now++;
        initBlock();
    }
    dsSetColor(1.0, 1.0, 0.0);   // 黄色

    for (i=0; i <= now; i++)
        dsDrawSphere(block_p[i], R, 0.5);
}

// ブロックが他のブロックと衝突したら１を返す，それ以外は０を返す
int collision()
{
    //　ブロック間の距離が１未満なら１を返すコードを
    //  ここに書きなさい
     return 0;
}

void simLoop(int pause)        /***  シミュレーションループ　***/
{
    if (collision()) {
        now++;
        initBlock();
    }
    drawBlock(); // ブロックの表示
    drawField();   // 壁の表示
}

int main()         /*** main関数 ***/
{
    initBlock();
    srand(time(NULL)); // 乱数の初期化
    dmLoop(800, 600); // シミュレーションループ ウインドウの幅，高
    return 0;
}


